//-----------------------------------------------------------------------
// <copyright file="ComboBase.cs" company="AgTrax">
//     Copyright (c) AgTrax. All rights reserved.
// </copyright>
// <author>Michael Halsig</author>
//-----------------------------------------------------------------------

namespace hared.BaseControls
{
    using System;
    using System.ComponentModel;
    using System.Windows.Forms;

    /// <summary>
    /// Combo Base User Control
    /// </summary>
    public partial class ComboBase : UserControl
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="ComboBase"/> class.
        /// </summary>
        public ComboBase()
        {
            this.InitializeComponent();

            // Override the row sizing because all rows should be sized to allow the largest value to display.
            this.ultraCombo1.DisplayLayout.Override.RowSizing = Infragistics.Win.UltraWinGrid.RowSizing.AutoFree;

            // Set fore color disabled
            this.ultraCombo1.DisplayLayout.Appearance.ForeColorDisabled = ControlPaint.Light(System.Drawing.Color.Black);
        }

        /// <summary>
        /// Disables the row.
        /// </summary>
        /// <param name="rowValue">The row value.</param>
        public void DisableRow(object rowValue)
        {
            foreach (Infragistics.Win.UltraWinGrid.UltraGridRow row in this.ultraCombo1.Rows)
            {
                if (row.Cells["Value"].Value.ToString() == rowValue.ToString())
                {
                    row.Activation = Infragistics.Win.UltraWinGrid.Activation.Disabled;
                    break;
                }
            }
        }

        /// <summary>
        /// Gets the 32-bit integer value.
        /// </summary>
        /// <returns>Value member as an 32-bit integer</returns>
        public int GetInt32Value()
        {
            // Check to see if the value is null.
            if (this.ultraCombo1.Value != null)
            {
                return Convert.ToInt32(this.ultraCombo1.Value);
            }
            else
            {
                return 0;
            }
        }

        /// <summary>
        /// Gets the 64-bit integer value.
        /// </summary>
        /// <returns>Value member as an 64-bit integer</returns>
        public long GetInt64Value()
        {
            // Check to see if the value is null.
            if (this.ultraCombo1.Value != null)
            {
                return Convert.ToInt64(this.ultraCombo1.Value);
            }
            else
            {
                return 0;
            }
        }

        /// <summary>
        /// Gets the object value.
        /// </summary>
        /// <returns>The value of the combo editor.</returns>
        public object GetObjectValue()
        {
            // Check to see if the value is null.
            if (this.ultraCombo1.Value != null)
            {
                return this.ultraCombo1.Value;
            }
            else
            {
                return string.Empty;
            }
        }

        /// <summary>
        /// Gets the value.
        /// </summary>
        /// <returns>The string value of the combo editor.</returns>
        public string GetValue()
        {
            // Check to see if the value is null.
            if (this.ultraCombo1.Value != null)
            {
                return this.ultraCombo1.Value.ToString();
            }
            else
            {
                return string.Empty;
            }
        }

        /// <summary>
        /// Gets the values.
        /// </summary>
        /// <returns>Array of values.</returns>
        public string[] GetValues()
        {
            return new string[] { string.Empty };
        }

        /// <summary>
        /// Sets the value.
        /// </summary>
        /// <param name="setValue">The set value.</param>
        /// <param name="clearErrors">if set to <c>true</c> [clear errors].</param>
        public void SetValue(object setValue, bool clearErrors = true)
        {
            // Clear the errors if needed
            if (clearErrors)
            {
                this.ClearErrors();
            }

            // Set the value.
            this.ultraCombo1.Value = setValue;
        }

        /// <summary>
        /// Clears the errors.
        /// </summary>
        private void ClearErrors()
        {
            // Always clear the error provider before setting the new value.
            this.errorProvider1.Clear();
        }

        /// <summary>
        /// Handles the Leave event of the ComboBase control.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="EventArgs"/> instance containing the event data.</param>
        private void ComboBase_Leave(object sender, EventArgs e)
        {
            this.ClearErrors();
        }

        /// <summary>
        /// Handles the Resize event of the ComboBase control.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="EventArgs"/> instance containing the event data.</param>
        private void ComboBase_Resize(object sender, EventArgs e)
        {
            this.ultraCombo1.Size = ((Control)sender).Size;
        }
    }
}